TODO:
- write wiki

new features/bugs/requests:
https://github.com/shakamaran/nproan/issues

COL vs ROW Convention:

In ROOT its (col, row), but:
data is represented as (frame,row,nreps,col), so i will use (row, col) here

Steps to upload package:
https://packaging.python.org/en/latest/tutorials/packaging-projects/